// Router | Binds Models to Routes Using Helper | RMY

var routes = {
    account: require('./routes/account'),
    nc: require('./routes/nc'),
    pets: require('./routes/pets'),
    users: require('./routes/users')
};

// Check if user is logged in
var checkAuth = function(req, res, next) {
    if(req.loggedIn){
        next();
    } else {
        console.log('User is not logged in. Redirected to login...');
        res.render('login');
    }
};

// Check if user role is admin
var checkAdmin = function(req, res, next) {
    if (req.user.role == 'Admin') {
        return next();
    } else {
        console.log('User is not an Admin. Redirecting to restricted error...');
        return res.render('error');
    }
    // WARN: Potential security vulnerability if req.originalUrl isn't escaped properly
    //var loginUrl = '/login?redirect=' + req.originalUrl;
    //res.redirect(loginUrl);
};

exports.route = function(app, db) {
    var m = function(route) {
        var models = {
            Pet: db.Pet,
            Nc: db.Nc,
            User: db.User
        };

        return route.bind(null, models);
    };


    // Authentication & ACL

    //app.get('/logout', routes.auth.logout);
    app.all('*', checkAuth);

    app.get('/', function(req, res) {res.render('index');});
    app.get('/login', function(req, res) {res.render('login');});

    // Account
    app.get('/account', m(routes.account.index));
    app.get('/account/nc', m(routes.account.nc));
    app.get('/account/pets', m(routes.account.pets));

    // Pets
    app.get('/pets', m(routes.pets.index));
    app.get('/pets/:id', m(routes.pets.detailView));
    app.get('/pets/add', m(routes.pets.addView));
    app.get('/pets/:id/edit', m(routes.pets.editView));
    app.post('/pets', m(routes.pets.addAction));
    app.put('/pets/:id', m(routes.pets.editAction));
    app.delete('/pets/:id', m(routes.pets.deleteAction));

    // Nc
    app.get('/nc', m(routes.nc.index));

    // Users
    app.get('/users', routes.users.index);
    app.get('/users/:id', m(routes.users.detailView));
    app.post('/users', m(routes.users.addAction));
    app.put('/users/:id', m(routes.users.editAction));
    app.delete('/users/:id', m(routes.users.deleteAction));
};