// Pets Controller

// ---------------------- Declarations ---->>


// ---------------------- Routes ---->>

// List Pets
exports.index = function (models, req, res) {
    var Pet = models.Pet;
    Pet
        .findAll()
        .success(function(pets) {res.render('pets/index', {pets: pets})})
        .error(function(err) {console.log('Error: ' + err)})
};


// Add Pet View
exports.addView = function(req, res) {
    res.render('pets/add');
};

// Get Pet by ID View
exports.detailView = function(models, req, res) {
    var Pet = models.Pet;
    Pet
        .find({where: {id: req.params.id}})
        .success(function(pet, err) {
            // project will be an instance of Project and stores the content of the table entry
            // with id 123. if such an entry is not defined you will get null
            if (err) {
                res.send(err);
                console.log('Unknown pet requested...');
            } else {
                console.log('Successfully found requested pet: ' + pet);
                res.render('pets/view', {
                    // Stuff that you want to render within the view goes here.
                    name: pet.name,
                    description: pet.description,
                    pet: pet
                });
            }
        });
};


// Edit View
exports.editView = function(models, req, res) {
    var Pet = models.Pet;
    Pet
        .find({where: {id: req.params.id}})
        .success(function(pet) {
            res.render('pets/edit', {pet: pet});
        })
        .error(function(err) {
            console.log('Error finding pet: ' + err);
            res.redirect('/pets');
        });
};


// Generic Route Mapping
exports.routes = function(req, res) {
    console.log('Rendering /pets/' + req.params.name);
    res.render('pets/' + req.params.name);
};



// ---------------------- API ---->>

// Add Pet Action
exports.addAction = function (models, req, res) {
    var Pet = models.Pet;
    var input = req.body.pet;
    var pet = {
        sku: input.sku,
        name: input.name,
        color : input.color,
        description: input.description
    };
    Pet
        .create(pet)
        .success(function(pet, err) {
            if (err) {
                res.send(err);
            } else {
                console.log('Successfully created pet: ' + pet);
                res.render('pets/add-success', {pet: pet});
            }
        });
};


// Count All Pets
exports.countPets = function(models, req, res) {
    var Pet = models.Pet;
    Pet
        .count()
        .success(function(count, err) {
            if (err) {
                res.send(err);
                console.log('There was an error with retrieving the number of pets from the database.');
            } else {
                res.send(JSON.stringify(count));
                console.log("There are " + count + " pets!");
            }
        })
};


// Edit Pet Action
exports.editAction = function(models, req, res) {
    var Pet = models.Pet;
    Pet
        .find({ where: {id: req.params.id} })
        .on('success', function(pet) {
            if (pet) { // if the record exists in the db
                pet
                    .updateAttributes({
                        sku: req.body.pet.sku,
                        name: req.body.pet.name,
                        description: req.body.pet.description
                    })
                    .success(function(result) {
                        console.log('Successfully updated pet: ' + result);
                    })
                    .error(function(err) {
                        console.log('Error: ' + err);
                    });
            }
        });
};

// Delete Pet Action
exports.deleteAction = function(models, req, res) {
    var Pet = models.Pet;
    Pet
        .find({where: {id: req.params.id}})
        .success(function(pet) {
            pet.destroy()
                .success(function() {console.log('Successfully deleted!');})})
        .error(function(err) {console.log('Error: ' + err);})
};


