// Users Controller

// ---------------------- Declarations ---->>

var _ = require('underscore');
var async = require('async');
var lodash = require('lodash');
var uuid = require('node-uuid');


// ---------------------- Routes ---->>

// Users Index
exports.index = function(models, req, res) {
    var User = models.User;
    User
        .findAll()
        .success(function(users) {
            res.render('users', {users: users});
        })
        .error(function(err) {
            console.log('Error retrieving users: ' + err);
        });
};

// Add User View
exports.addView = function(models, req, res) {
    res.render('users/add');
};

// User Detail View
exports.detailView = function(models, req, res) {
    var User = models.User;
    User
        .find({where: {id: req.params.id}})
        .success(function(user) {
            res.render('users/view', {user: user});
        })
        .error(function(err) {
            console.log('Error retrieving user: ' + err);
        })
};

// Edit User View
exports.editView = function(models, req, res) {
    var User = models.User;
    User
        .find({where: {id: req.params.id}})
        .success(function(user) {
            res.render('users/view', {user: user});
        })
        .error(function(err) {
            console.log('Error retrieving user: ' + err);
        })
};


// ---------------------- API ---->>


// Add User Action
exports.addAction = function(models, req, res) {
    var User = models.User;
    var input = req.body.user;
    var user = {
        id: uuid.v4(),
        username: input.username,
        name: input.name,
        email: input.email,
        password: input.password,
        description: input.description
    };

    User
        .create(user)
        .success(function(user, err) {
            if (err) {
                res.send(err);
            } else {
                res.send(JSON.stringify(user));
                res.redirect('registerSuccess');
            }
        });
};

// Delete User Action
exports.deleteAction = function(models, req, res) {
    var User = models.User;
    User
        .find({where: {id: req.params.id}})
        .success(function(user) {
            user
                .destroy()
                .success(function(){
                    console.log('Successfully deleted user...');
                    res.render('users');
                })
                .error(function() {
                    console.log('Error deleting user: ' + err);
                    res.render('error');
                });
        })
        .error(function(err) {
            console.log('Error retrieving user: ' + err);
            res.render('error/not-found');
        });
};

// Edit User Action
exports.editAction = function(models, req, res) {
    var User = models.User;
};